Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(877)

Unified Diff: scripts/slave/recipes/flutter/engine.py

Issue 1788653004: Fix bot_update api rename. (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/build.git@master
Patch Set: Long line. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « scripts/slave/recipe_modules/v8/api.py ('k') | scripts/slave/recipes/swarming/staging.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: scripts/slave/recipes/flutter/engine.py
diff --git a/scripts/slave/recipes/flutter/engine.py b/scripts/slave/recipes/flutter/engine.py
index 1667757f405e4149b0fa5264a28d37a5e8fa92a1..93c77fe4a9972ccdd509c58cde40936c03a9845e 100644
--- a/scripts/slave/recipes/flutter/engine.py
+++ b/scripts/slave/recipes/flutter/engine.py
@@ -19,9 +19,9 @@ DEPS = [
BUCKET_NAME = 'flutter_infra'
def GetCloudPath(api, path):
- # TODO(eseidel): api.bot_update.properties is supposedly a known api wart.
- # iannucci says it will be improved at some point.
- git_hash = api.bot_update.properties['got_engine_revision']
+ # TODO(eseidel): api.bot_update.last_returned_properties is supposedly a known
+ # api wart. iannucci says it will be improved at some point.
+ git_hash = api.bot_update.last_returned_properties['got_engine_revision']
return 'flutter/%s/%s' % (git_hash, path)
« no previous file with comments | « scripts/slave/recipe_modules/v8/api.py ('k') | scripts/slave/recipes/swarming/staging.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698